function [List] = readpanel(line,List,panelsize)
% Reads a panel with vertices as floating point numbers on a line
% Input
%  line <- line to be parsed, Q or T format
%  List <- Internal data structure
%  panelsize <- 3 for T format, 4 for Q format
  [stuff,cnt]=sscanf(line,'%s %d %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f');

  % Check if Q or T format is OK.
  if (cnt == (2 + panelsize * 3)) 
    fastcap = 1;
    fastlap = 0;
  elseif (cnt == (2 + 3 + panelsize * 3)) 
    fastcap = 0;
    fastlap = 1;
  else
    disp('Format error in panel!');
    return;
  end

  [rows,cols,numpanels] = size(List);

  % Add one data structuer
  numpanels = numpanels +1; 
  List(1,1,numpanels) = panelsize;
  List(1,2,numpanels) = stuff(2);
  List(1,3,numpanels) = 0;

  % fastlap == 1 means T format
  % panelsize + 2 is always 5
  if(fastlap == 1) 
    List(panelsize+2,1,numpanels) = stuff(cnt - 2);  % Potential
    List(panelsize+2,2,numpanels) = stuff(cnt - 1);  % d/dn Potential
    List(panelsize+2,3,numpanels) = stuff(cnt);      % Type
  end;

  % stuff(index <- 3) is where the data starts.
  index = 3;
  for i=2:panelsize+1
    for j=1:3
      List(i,j,numpanels) = stuff(index);
      index = index + 1;
    end
  end
